@@ -8,8 +8,8 @@
 
 """invenio module that adds tugraz configs."""
 
-from .ext import invenioconfigtugraz
+from .ext import InvenioConfigTugraz
 from .generators import RecordIp
 from .version import __version__
 
-__all__ = ('__version__', 'invenioconfigtugraz', 'RecordIp')
+__all__ = ("__version__", "InvenioConfigTugraz", "RecordIp")
